#!/bin/sh

for i in 16 24 32 48 64 75 128 256 512 1024
do
    convert anaconda-icon-large-1.png \
        -resize ${i}x${i} \
        -gravity center \
        -background transparent \
        -extent ${i}x${i} \
        anaconda-icon-${i}x${i}.png
done

# Including all the sizes seems to corrupt the icon
convert anaconda-icon-{64x64,256x256}.png anaconda-ui.ico

cp anaconda-ui.ico favicon.ico
