# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright 2016 Continuum Analytics, Inc.
#
# May be copied and distributed freely only as part of an Anaconda or
# Miniconda installation.
# -----------------------------------------------------------------------------
"""Anaconda Navigator setup script."""

# Third party imports
from setuptools import find_packages, setup
from setuptools.command.install import install

# Local imports
from anaconda_navigator import __version__

packages = find_packages()
setup(
    name='anaconda-navigator',
    version=__version__,
    description='Anaconda Navigator',
    author='Continuum Analytics',
    packages=packages,
    package_data={
        'anaconda_navigator.static.content': ['*.json', '*.json.bz2', '*.bz2'],
        'anaconda_navigator.static.css': ['*.css', '*.scss'],
        'anaconda_navigator.static.fonts': ['*.ttf'],
        'anaconda_navigator.static.images':
        ['*.jpg', '*.jpeg', '*.png', '*.gif', '*.svg', 'icons/*'],
    },
    entry_points={
        'gui_scripts':
        ['anaconda-navigator = anaconda_navigator.app.main:main']
    },
    include_package_data=True,
)
