#!/bin/bash

# Remove old Navigator desktop file if it exists
rm -f $PREFIX/anaconda-navigator.desktop

cp $PREFIX/navigator.desktop $PREFIX/anaconda-navigator.desktop
rm -f $PREFIX/navigator.desktop

xdg-desktop-menu install $PREFIX/anaconda-navigator.desktop || exit 0
