# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2016-2017 Anaconda, Inc.
#
# May be copied and distributed freely only as part of an Anaconda or
# Miniconda installation.
# -----------------------------------------------------------------------------
"""Tests for bundled image content."""

# yapf: disable

# Standard library imports
import os

# Local imports
from anaconda_navigator.static import images


# yapf: enable


# --- Tests
# -----------------------------------------------------------------------------
def test_bundled_images_exist():
    variables = [var for var in dir(images) if var.isupper()]
    paths = [getattr(images, var) for var in variables]
    for path in paths:
        print(path)
        assert os.path.isdir(path) or os.path.isfile(path)
